# <h1> cybertnetica<sub><sub><sup>is a auotomata to package,publish and validate my simple project(s) .</sup></sub></sub></h1><br>

## Preface

image that you are facing a scenario: 

*  frequently build docker image(s) ,more than 2 times a day.
*  20 vm(s) to deploy.

**Note:** * Same procedure will be executed in each one of the vm .*

## cybertnetica

cybertnetica is an AUTOMATA.  cybertnetica will...

* Greatly reduce the time for packaging and publishing
* Retrieve a certain result to validate the deployment 

cybertnetica will _not_...

* Take the place of routine monitoring
* Aware of hardware malfunction


### Installation

First of all we have to install it:
```Shell
pip install cybertnetica
```
I recommend using the parameter ``-i https://pypi.douban.com/simple`` via the the installation above in person.